@@ -84,8 +84,8 @@ class Shared:
         ranked_shares_df['ct_shares_count']=shares_gb['id'].transform('nunique')
         ranked_shares_df['first_share_date'] = shares_gb['date'].transform('min')
         ranked_shares_df['rank'] = shares_gb['date'].rank(ascending=True, method='first')
-        #ranked_shares_df['perc_of_shares'] = ranked_shares_df['rank']/ranked_shares_df['ct_shares_count']
-        ranked_shares_df['perc_of_shares'] = shares_gb['date'].rank(ascending=True)
+        ranked_shares_df['perc_of_shares'] = ranked_shares_df['rank']/ranked_shares_df['ct_shares_count']
+        #ranked_shares_df['perc_of_shares'] = shares_gb['date'].rank(ascending=True)
         ranked_shares_df['sec_from_first_share'] = (ranked_shares_df['date'] - ranked_shares_df['first_share_date']).dt.total_seconds()
         ranked_shares_df = ranked_shares_df.sort_values(by = 'expanded')
 
@@ -352,7 +352,7 @@ class Shared:
 
             crowtangle_shares_df = crowtangle_shares_df.reset_index(drop=True)
             crowtangle_shares_df.loc[:,'coord_expanded']=crowtangle_shares_df['expanded'].isin(coordinated_shares_df['url'])
-            crowtangle_shares_df.loc[:,'coord_date']=crowtangle_shares_df['date'].isin(coordinated_shares_df['share_date']).values
+            crowtangle_shares_df.loc[:,'coord_date']=crowtangle_shares_df['date'].astype('datetime64[ns]').isin(coordinated_shares_df['share_date'])
             crowtangle_shares_df.loc[:,'coord_account_url']=crowtangle_shares_df['date'].isin(coordinated_shares_df['share_date']).values
 
             crowtangle_shares_df.loc[:,'is_coordinated'] = crowtangle_shares_df.apply(lambda x : True if (x['coord_expanded'] and x['coord_date'] and x['coord_account_url']) else False, axis=1)
